# -*- coding: utf-8 -*-

from celery.backends.redis import RedisBackend
from celery.utils import cached_property


class RedisUnixSocketBackend(RedisBackend):

    @cached_property
    def client(self):
        if self.host.startswith('/'):
            pool = self.redis.ConnectionPool(
                connection_class=self.redis.UnixDomainSocketConnection,
                path=self.host,
                db=self.db,
                password=self.password,
            )
            return self.redis.Redis(connection_pool=pool)
        else:
            return super(RedisUnixSocketBackend, self).client



# -*- coding: utf-8 -*-

from kombu.transport import redis as kombu_redis
import redis


class Channel(kombu_redis.Channel):

    def _create_client(self):
        conninfo = self.connection.client
        database = conninfo.virtual_host
        if not isinstance(database, int):
            if not database or database == "/":
                database = kombu_redis.DEFAULT_DB
            elif database.startswith("/"):
                database = database[1:]
            try:
                database = int(database)
            except ValueError:
                raise ValueError(
                    "Database name must be int between 0 and limit - 1")
        if conninfo.hostname and conninfo.hostname.startswith('/'):
            pool = redis.ConnectionPool(
                connection_class=redis.UnixDomainSocketConnection,
                path=conninfo.hostname,
                db=database,
                password=conninfo.password,
            )
        else:
            pool = None

        return self.Client(
            host=conninfo.hostname,
            port=conninfo.port or kombu_redis.DEFAULT_PORT,
            db=database,
            password=conninfo.password,
            connection_pool=pool,
        )


class Transport(kombu_redis.Transport):
    Channel = Channel



# -*- coding: utf-8 -*-

__version__ = '0.2'

try:
    from celery.backends import BACKEND_ALIASES
    BACKEND_ALIASES['redisunixsocket'] = 'celery_redis_unixsocket.store.RedisUnixSocketBackend'
except ImportError:
    pass



import metadata as m

from setuptools import setup, find_packages

install_requires = [
    "redis",
    "kombu",
    "celery",
]

setup(
    name=m.name,
    version=m.version,
    url=m.project_url,
    license=m.license,
    platforms=['OS Independent'],
    description=m.description,
    author=m.author,
    author_email=m.author_email,
    packages=find_packages(),
    install_requires=install_requires,
    include_package_data=True,  # Accept all data files and directories matched by MANIFEST.in or found in source control.
    package_dir={
        m.package_name: m.package_name,
    },
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ]
)



package_name = 'celery_redis_unixsocket'
name = 'celery-redis-unixsocket'
author = 'Benjamin Wohlwend'
author_email = 'piquadrat@gmail.com'
description = "celery store backend and kombu transport for redis that supports connections via unix sockets"
version = __import__(package_name).__version__
project_url = 'http://github.com/piquadrat/%s' % name
license = 'BSD'
